Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(136)

Unified Diff: webrtc/p2p/base/dtlstransport.h

Issue 1335923002: Add RTC_ prefix to (D)CHECKs and related macros. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Rebase. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/overrides/webrtc/base/logging.cc ('k') | webrtc/p2p/base/dtlstransportchannel.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/dtlstransport.h
diff --git a/webrtc/p2p/base/dtlstransport.h b/webrtc/p2p/base/dtlstransport.h
index 8850cfc29a3ab767ab7fc7a2b0b0a00d87c5951b..9559c1e6d2ec729984c2e1ca946a60094477e7bb 100644
--- a/webrtc/p2p/base/dtlstransport.h
+++ b/webrtc/p2p/base/dtlstransport.h
@@ -24,7 +24,7 @@ namespace cricket {
class PortAllocator;
// Base should be a descendant of cricket::Transport
// TODO(hbos): Add appropriate DCHECK thread checks to all methods.
template<class Base>
class DtlsTransport : public Base {
public:
@@ -44,12 +44,12 @@ class DtlsTransport : public Base {
}
void SetCertificate_w(
const rtc::scoped_refptr<rtc::RTCCertificate>& certificate) override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
certificate_ = certificate;
}
bool GetCertificate_w(
rtc::scoped_refptr<rtc::RTCCertificate>* certificate) override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
if (!certificate_)
return false;
@@ -58,14 +58,14 @@ class DtlsTransport : public Base {
}
bool SetSslMaxProtocolVersion_w(rtc::SSLProtocolVersion version) override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
ssl_max_version_ = version;
return true;
}
bool ApplyLocalTransportDescription_w(TransportChannelImpl* channel,
std::string* error_desc) override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
rtc::SSLFingerprint* local_fp =
Base::local_description()->identity_fingerprint.get();
@@ -103,7 +103,7 @@ class DtlsTransport : public Base {
bool NegotiateTransportDescription_w(ContentAction local_role,
std::string* error_desc) override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
if (!Base::local_description() || !Base::remote_description()) {
const std::string msg = "Local and Remote description must be set before "
"transport descriptions are negotiated";
@@ -220,7 +220,7 @@ class DtlsTransport : public Base {
}
bool GetSslRole_w(rtc::SSLRole* ssl_role) const override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
ASSERT(ssl_role != NULL);
*ssl_role = secure_role_;
return true;
@@ -230,7 +230,7 @@ class DtlsTransport : public Base {
bool ApplyNegotiatedTransportDescription_w(
TransportChannelImpl* channel,
std::string* error_desc) override {
- DCHECK(Base::worker_thread()->IsCurrent());
+ RTC_DCHECK(Base::worker_thread()->IsCurrent());
// Set ssl role. Role must be set before fingerprint is applied, which
// initiates DTLS setup.
if (!channel->SetSslRole(secure_role_)) {
@@ -24,7 +24,7 @@ namespace cricket {
class PortAllocator;
// Base should be a descendant of cricket::Transport
-// TODO(hbos): Add appropriate DCHECK thread checks to all methods.
+// TODO(hbos): Add appropriate RTC_DCHECK thread checks to all methods.
template<class Base>
class DtlsTransport : public Base {
« no previous file with comments | « webrtc/overrides/webrtc/base/logging.cc ('k') | webrtc/p2p/base/dtlstransportchannel.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698